----------
Exceptions
----------

.. currentmodule:: oslo_config.cfg

.. autoexception:: Error
.. autoexception:: ArgsAlreadyParsedError
.. autoexception:: NoSuchOptError
.. autoexception:: NoSuchGroupError
.. autoexception:: DuplicateOptError
.. autoexception:: RequiredOptError
.. autoexception:: TemplateSubstitutionError
.. autoexception:: ConfigFilesNotFoundError
.. autoexception:: ConfigFileParseError
.. autoexception:: ConfigFileValueError
